@@ -1,6 +1,9 @@
 from pathlib import Path
 
-from jinja2 import Environment, FileSystemLoader
+from jinja2 import (
+    Environment,
+    FileSystemLoader,
+)
 
 environment = Environment(
     loader=FileSystemLoader(str(Path(__file__).parent / "templates"))
